@@ -1,7 +1,9 @@
 from .BubbleTrain import BubbleTrain
+from .GridLayout import GridLayout
 from .TextInput import TextInput
 
 __all__ = [
     "BubbleTrain",
+    "GridLayout",
     "TextInput"
 ]
\ No newline at end of file
